@@ -167,7 +167,13 @@ class ClusterClient(client.MagnumClient):
 
     def does_cluster_not_exist(self, cluster_id):
         try:
-            self.get_cluster(cluster_id)
+            resp, model = self.get_cluster(cluster_id)
+            if model.status in ['ERROR', 'DELETE_FAILED']:
+                self.LOG.error('Cluster %s is in failed state, status_reason: '
+                               '%s', cluster_id, model.status_reason)
+                raise exceptions.ServerFault(
+                    "Got into an error condition: %s for %s" %
+                    (model.status, cluster_id))
         except exceptions.NotFound:
             self.LOG.warning('Cluster %s is not found.', cluster_id)
             return True
